@@ -9,6 +9,7 @@ def compute(cfg, inputDataFrame):
                             sep=cfg["sep"],
                             suffix= {"string": "\w+", "number": "\d+"}[cfg["suffix"]]
                             ).reset_index()
+
     return output
 
 
@@ -16,6 +17,6 @@ def dimensions(cfg, inputDataFrame):
     return [
         *cfg["i"],
         *[c for c in inputDataFrame.columns
-          if cfg["sep"] in c and c.split(cfg["sep"])[0] in cfg["stubnames"]
+          if cfg["sep"] in c and cfg["sep"].join(c.split(cfg["sep"])[:-1]) in cfg["stubnames"]
           ]
     ]
